@@ -1,24 +1,26 @@
 """Define an object to interact with provisioning info."""
-from typing import Awaitable, Callable
+from __future__ import annotations
+
+from typing import Any, Awaitable, Callable, cast
 
 
 class Provision:
     """Define a provisioning object."""
 
-    def __init__(self, request: Callable[..., Awaitable[dict]]) -> None:
+    def __init__(self, request: Callable[..., Awaitable[dict[str, Any]]]) -> None:
         """Initialize."""
-        self._request: Callable[..., Awaitable[dict]] = request
+        self._request = request
 
     @property
     async def device_name(self) -> str:
         """Get the name of the device."""
-        data: dict = await self._request("get", "provision/name")
-        return data["name"]
+        data = await self._request("get", "provision/name")
+        return cast(str, data["name"])
 
-    async def settings(self) -> dict:
+    async def settings(self) -> dict[str, Any]:
         """Get a multitude of settings info."""
         return await self._request("get", "provision")
 
-    async def wifi(self) -> dict:
+    async def wifi(self) -> dict[str, Any]:
         """Get wifi info from the device."""
         return await self._request("get", "provision/wifi")
